==> kubernetes-model-0.1.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/EndpointAddressFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class EndpointAddressFluent<T extends EndpointAddressFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String ip;     VisitableBuilder<ObjectReference, ?> targetRef;     Map<String, Object> additionalProperties = new HashMap();

    public String getIp(){
    return this.ip;
    }
    public T withIp( String ip){
    this.ip=ip; return (T) this;
    }
    public ObjectReference getTargetRef(){
    return this.targetRef!=null?this.targetRef.build():null;
    }
    public T withTargetRef( ObjectReference targetRef){
    if (targetRef!=null){ this.targetRef= new ObjectReferenceBuilder(targetRef); _visitables.add(this.targetRef);} return (T) this;
    }
    public TargetRefNested<T> withNewTargetRef(){
    return new TargetRefNested<T>();
    }
    public TargetRefNested<T> withNewTargetRefLike( ObjectReference item){
    return new TargetRefNested<T>(item);
    }
    public TargetRefNested<T> editTargetRef(){
    return withNewTargetRefLike(getTargetRef());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }

    public class TargetRefNested<N> extends ObjectReferenceFluent<TargetRefNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             TargetRefNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
             TargetRefNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
    
            public N and(){
            return (N) EndpointAddressFluent.this.withTargetRef(builder.build());
        }
            public N endTargetRef(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.7-sources.jar: annotations/io/fabric8/kubernetes/api/model/EndpointAddressFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class EndpointAddressFluent<T extends EndpointAddressFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String ip;     VisitableBuilder<ObjectReference, ?> targetRef;     Map<String, Object> additionalProperties = new HashMap();

    public String getIp(){
    return this.ip;
    }
    public T withIp( String ip){
    this.ip=ip; return (T) this;
    }
    public ObjectReference getTargetRef(){
    return this.targetRef!=null?this.targetRef.build():null;
    }
    public T withTargetRef( ObjectReference targetRef){
    if (targetRef!=null){ this.targetRef= new ObjectReferenceBuilder(targetRef); _visitables.add(this.targetRef);} return (T) this;
    }
    public TargetRefNested<T> withNewTargetRef(){
    return new TargetRefNested<T>();
    }
    public TargetRefNested<T> withNewTargetRefLike( ObjectReference item){
    return new TargetRefNested<T>(item);
    }
    public TargetRefNested<T> editTargetRef(){
    return withNewTargetRefLike(getTargetRef());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
EndpointAddressFluent that = (EndpointAddressFluent) o;
if (ip != null ? !ip.equals(that.ip) :that.ip != null) return false;
if (targetRef != null ? !targetRef.equals(that.targetRef) :that.targetRef != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class TargetRefNested<N> extends ObjectReferenceFluent<TargetRefNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             TargetRefNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             TargetRefNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N endTargetRef(){
            return and();
        }
            public N and(){
            return (N) EndpointAddressFluent.this.withTargetRef(builder.build());
        }
    
}


}
